@@ -17,7 +17,7 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-# $Id: test.pl,v 1.7 2003/05/24 20:50:22 rousseau Exp $
+# $Id: test.pl,v 1.12 2004/05/30 20:10:11 rousseau Exp $
 
 use ExtUtils::testlib;
 use Chipcard::PCSC;
@@ -36,8 +36,6 @@ my $SendData;
 my $RecvData;
 my $sw;
 
-#my @ConnectionContext;
-
 #-------------------------------------------------------------------------------
 print "Getting context:\n";
 $hContext = new Chipcard::PCSC();
@@ -52,6 +50,38 @@ $, = "\n  ";
 $" = "\n  ";
 print "  @ReadersList\n" . '.'x40 . " OK\n";
 
+#-------------------------------------------------------------------------------
+print "Getting status change:\n";
+my (@readers_states, $reader_state, $timeout, $event_state);
+# create the list or readers to watch
+map { push @readers_states, ({'reader_name'=>"$_"}) } @ReadersList;
+
+@StatusResult = $hContext->GetStatusChange(\@readers_states);
+
+for my $i (0..$#readers_states)
+{
+	print "reader: " . $readers_states[$i]{'reader_name'} . "\n";
+	print "  ATR: " .
+	Chipcard::PCSC::array_to_ascii($readers_states[$i]{'ATR'}) .  "\n" if (defined $readers_states[$i]{'ATR'});
+	print "  state:\n";
+	$event_state = $readers_states[$i]{'event_state'};
+	print "    state changed\n" if ($event_state & $Chipcard::PCSC::SCARD_STATE_CHANGED);
+	print "    card present\n" if ($event_state & $Chipcard::PCSC::SCARD_STATE_PRESENT);
+	print "    card abstent\n" if ($event_state & $Chipcard::PCSC::SCARD_STATE_EMPTY);
+	print "    card mute\n" if ($event_state & $Chipcard::PCSC::SCARD_STATE_MUTE);
+
+	$readers_states[$i]{'current_state'} = $event_state;
+}
+
+if (! ($readers_states[0]{'event_state'} &
+		$Chipcard::PCSC::SCARD_STATE_PRESENT))
+{
+	$timeout = 10 * 1000;	# 10 seconds
+	print "Insert a card in the first reader please (timeout in $timeout ms)\n";
+	@StatusResult = $hContext->GetStatusChange(\@readers_states, $timeout);
+}
+print '.'x40 . " OK\n";
+
 #-------------------------------------------------------------------------------
 print "Connecting to the card:\n";
 $hCard = new Chipcard::PCSC::Card ($hContext);
@@ -119,6 +149,20 @@ print "ISO7816Error:\n";
 print "$sw: " . &Chipcard::PCSC::Card::ISO7816Error($sw) . "\n";
 print '.'x40 . " OK\n";
 
+#-------------------------------------------------------------------------------
+# This test is commented since it is reader/driver specific and may do bad
+# things for another reader. Reader your reader and driver
+# specifications to know what data to use.
+#
+#print "Control\n";
+#$SendData = Chipcard::PCSC::ascii_to_array ("02");
+#$RecvData = $hCard->Control(0x42000001, $SendData);
+#die ("Can't Control data: $Chipcard::PCSC::errno") unless (defined ($RecvData));
+#
+#print "  Send -> " . Chipcard::PCSC::array_to_ascii ($SendData) . "\n";
+#print "  Recv <- " . Chipcard::PCSC::array_to_ascii ($RecvData) . "\n";
+#print '.'x40 . " OK\n";
+
 #-------------------------------------------------------------------------------
 print ("Ending transaction:\n");
 die ("Can't terminate transaction: $Chipcard::PCSC::errno\n") unless ($hCard->EndTransaction($Chipcard::PCSC::SCARD_LEAVE_CARD));
